from pathlib import Path

__all__ = ["install_requirements_from_file", "install_requirements_from_name"]

from typing import Iterable


def install_requirements_from_file(requirements_path: Path) -> None:
    """
    Install requirements from a requirements.txt file.

    :param requirements_path: Path to requirements.txt file.

    """

    # pip.main(["install", "pip", "--upgrade"]) # REQUIRES RESTART OF QGIS

    args = ["install", "-r", str(requirements_path), "--upgrade"]
    # args = ["install", "rasterio", "--upgrade"] # RASTERIO for window DOES NOT WORK ATM, should be installed manually

    if False:
        import pip

        pip.main(args)

    elif False:
        from subprocess import call

        call(["pip"] + args)

    elif True:
        from subprocess import call

        call(["python", "-m", "pip"] + args)


def install_requirements_from_name(requirements_name: Iterable[str]) -> None:
    """
    Install requirements from names.

    :param requirements_name: Name of requirements.
    """
    # pip.main(["install", "pip", "--upgrade"]) # REQUIRES RESTART OF QGIS

    args = ["install", *requirements_name, "--upgrade"]
    # args = ["install", "rasterio", "--upgrade"] # RASTERIO for window DOES NOT WORK ATM, should be installed manually

    if False:
        import pip

        pip.main(args)

    elif False:
        from subprocess import call

        call(["pip"] + args)

    elif True:
        from subprocess import call

        call(["python", "-m", "pip"] + args)



import numpy
from qgis.PyQt import QtGui
from qgis.core import QgsCoordinateReferenceSystem, QgsCoordinateTransform, QgsPoint

__all__ = ["get_qimage_from_numpy"]


def get_qimage_from_numpy(img, debug: bool = False) -> QtGui.QImage:
  # if isinstance(img, Image):
  #    img = img.data
  # if isinstance(img, numpy.ndarray):
  #    img = img.data

  # if isinstance(img, cv2.Image):
  #    img = img.data # QtGui.QImage.Format_BGR888
  # aformat = QImage.Format_RGB32

  img = img.data
  height, width, channels = img.shape
  if debug:
    print(f"height: {height}, width: {width}, channels: {channels}")
  bytes_per_line = channels * width
  img = numpy.require(img, numpy.uint8, "C")
  return QtGui.QImage(img, width, height, bytes_per_line, QtGui.QImage.Format_RGB888)


def transform_coordinates(coordinates, from_crs, to_crs) -> list:
  """

  function to transform a set of coordinates from one CRS to another"""
  crs_src = QgsCoordinateReferenceSystem(from_crs)
  crs_dest = QgsCoordinateReferenceSystem(to_crs)
  xform = QgsCoordinateTransform(crs_src, crs_dest)

  coordinates_as_points = [
      QgsPoint(coordinates[0], coordinates[1]),
      QgsPoint(coordinates[2], coordinates[3]),
      ]  # convert list of coordinates to QgsPoint objects

  transformed_coordinates_as_points = [
      xform.transform(point) for point in coordinates_as_points
      ]  # do transformation for each point

  return [
      transformed_coordinates_as_points[0].x(),
      transformed_coordinates_as_points[0].y(),
      transformed_coordinates_as_points[1].x(),
      transformed_coordinates_as_points[1].y(),
      ]  # transform the QgsPoint objects back to a list of coordinates


def get_coordinates_of_layer_extent(layer) -> list:
  """

  function to get coordinates of a layer extent

  """

  layerRectangle = layer.extent()

  return [
      layerRectangle.xMinimum(),
      layerRectangle.yMinimum(),
      layerRectangle.xMaximum(),
      layerRectangle.yMaximum(),
      ]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 5/5/22
           """


from .configuration import *
from .helpers import *
from .numpy_utilities import *



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 5/5/22
           """

from .conversion import *
from .enums import *
from .importing import *



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 5/5/22
           """

__all__ = ["import_gdal", "import_osr", "GDAL", "OSR"]


def import_gdal():
    """

    :return:
    :rtype:
    """
    try:
        import gdal
    except ImportError:
        try:
            from osgeo import gdal
        except:
            raise ImportError("gdal is not installed")
    gdal.UseExceptions()
    return gdal


def import_osr():
    """

    :return:
    :rtype:
    """
    try:
        import ors
    except ImportError:
        try:
            from osgeo import osr
        except:
            raise ImportError("osr is not installed")
    osr.UseExceptions()
    return osr


GDAL = import_gdal()
OSR = import_osr()

if __name__ == "__main__":
    import_gdal()
    import_osr()



import time

import numpy
from qgis.PyQt import QtGui, QtWidgets, uic
from qgis.PyQt.QtCore import pyqtSignal, Qt
from qgis.core import QgsGeometry
from qgis.core import QgsVectorLayer, QgsCoordinateReferenceSystem, QgsProject


__all__ = ["qt_draw_timestamp"]


def qt_draw_timestamp(
    image,
    font_size=10,
    font_color=(255, 255, 255),
    font_family="Arial",
    font_style=QtGui.QFont.StyleNormal,
    font_weight=QtGui.QFont.Normal,
):
    timestamp = time.strftime("%Y-%m-%d %H:%M:%S")
    font = QtGui.QFont(font_family, font_size, font_style, font_weight)
    font.setPixelSize(font_size)
    font.setBold(True)
    painter = QtGui.QPainter(image)
    painter.setFont(font)
    painter.setPen(QtGui.QColor(*font_color))
    painter.drawText(
        0,
        0,
        image.width(),
        image.height(),
        Qt.AlignCenter,
        timestamp,
    )
    painter.end()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

__author__ = "heider"
__doc__ = r"""

           Created on 5/5/22
           """

from .drawing import *
from .environment import *
from .models import *
from .progress_bar import *
from .signals import *
from .timestamp import *



__all__ = ["store_plugin_setting", "read_plugin_setting"]

from qgis.core import QgsSettings

from jord import PROJECT_NAME


def store_plugin_setting(key, value, *, project_name=PROJECT_NAME):
    QgsSettings().setValue(f"{project_name}/{key}", value)


def read_plugin_setting(key, *, default_value=None, project_name=PROJECT_NAME):
    return QgsSettings().value(f"{project_name}/{key}", default_value)


if __name__ == "__main__":
    store_plugin_setting("mytext", "hello world")
    print(read_plugin_setting("mytext"))
